@@ -105,6 +105,11 @@ void pval(unsigned long long valp, unsigned long long valc)
 /*
  ***************************************************************************
  * Display CPU statistics in raw format.
+ * Note: Values displayed for CPU "all" may slightly differ from those you
+ * would get if you were displaying them in pr_stats.c:print_cpu_stats().
+ * This is because values for CPU "all" are recalculated there as the sum of
+ * all individual CPU values (done by a call to get_global_cpu_statistics()
+ * function).
  *
  * IN:
  * @a		Activity structure with statistics.
@@ -1534,15 +1539,16 @@ __print_funct_t raw_print_filesystem_stats(struct activity *a, char *timestr, in
 __print_funct_t raw_print_fchost_stats(struct activity *a, char *timestr, int curr)
 {
 	int i, j, j0, found;
-	struct stats_fchost *sfcc, *sfcp;
+	struct stats_fchost *sfcc, *sfcp, sfczero;
+
+	memset(&sfczero, 0, sizeof(struct stats_fchost));
 
 	for (i = 0; i < a->nr[curr]; i++) {
 
 		found = FALSE;
+		sfcc = (struct stats_fchost *) ((char *) a->buf[curr] + i * a->msize);
 
 		if (a->nr[!curr] > 0) {
-			sfcc = (struct stats_fchost *) ((char *) a->buf[curr] + i * a->msize);
-
 			/* Look for corresponding structure in previous iteration */
 			j = i;
 
@@ -1565,10 +1571,17 @@ __print_funct_t raw_print_fchost_stats(struct activity *a, char *timestr, int cu
 			while (j != j0);
 		}
 
-		if (!found)
-			continue;
+		printf("%s; %s", timestr, pfield(a->hdr_line, FIRST));
 
-		printf("%s; %s; %s;", timestr, pfield(a->hdr_line, FIRST), sfcc->fchost_name);
+		if (!found) {
+			/* This is a newly registered host. Previous stats are zero */
+			sfcp = &sfczero;
+			if (DISPLAY_DEBUG_MODE(flags)) {
+				printf(" [NEW]");
+			}
+		}
+
+		printf("; %s;", sfcc->fchost_name);
 		printf(" %s", pfield(NULL, 0));
 		pval((unsigned long long) sfcp->f_rxframes, (unsigned long long) sfcc->f_rxframes);
 		printf(" %s", pfield(NULL, 0));
