@@ -538,11 +538,11 @@ void reallocate_all_buffers(struct activity *a, __nr_t nr_min)
   */
 char *get_devname_from_sysfs(unsigned int major, unsigned int minor)
 {
-	static char link[32], target[PATH_MAX];
+	static char link[256], target[PATH_MAX];
 	char *devname;
 	ssize_t r;
 
-	snprintf(link, 32, "%s/%u:%u", SYSFS_DEV_BLOCK, major, minor);
+	snprintf(link, 256, "%s/%u:%u", SYSFS_DEV_BLOCK, major, minor);
 
 	/* Get full path to device knowing its major and minor numbers */
 	r = readlink(link, target, PATH_MAX);
@@ -1314,12 +1314,17 @@ int remap_struct(unsigned int gtypes_nr[], unsigned int ftypes_nr[],
 	/* Remap [unsigned] long fields */
 	d = gtypes_nr[0] - ftypes_nr[0];
 	if (d) {
+		if (ftypes_nr[0] * ULL_ALIGNMENT_WIDTH < ftypes_nr[0])
+			/* Overflow */
+			return -1;
+
 		n = MINIMUM(f_size - ftypes_nr[0] * ULL_ALIGNMENT_WIDTH,
 			    g_size - gtypes_nr[0] * ULL_ALIGNMENT_WIDTH);
 		if ((ftypes_nr[0] * ULL_ALIGNMENT_WIDTH >= b_size) ||
 		    (gtypes_nr[0] * ULL_ALIGNMENT_WIDTH + n > b_size) ||
 		    (ftypes_nr[0] * ULL_ALIGNMENT_WIDTH + n > b_size))
 			return -1;
+
 		memmove(((char *) ps) + gtypes_nr[0] * ULL_ALIGNMENT_WIDTH,
 			((char *) ps) + ftypes_nr[0] * ULL_ALIGNMENT_WIDTH, n);
 		if (d > 0) {
@@ -1330,6 +1335,10 @@ int remap_struct(unsigned int gtypes_nr[], unsigned int ftypes_nr[],
 	/* Remap [unsigned] int fields */
 	d = gtypes_nr[1] - ftypes_nr[1];
 	if (d) {
+		if (ftypes_nr[1] * UL_ALIGNMENT_WIDTH < ftypes_nr[1])
+			/* Overflow */
+			return -1;
+
 		n = MINIMUM(f_size - ftypes_nr[0] * ULL_ALIGNMENT_WIDTH
 				   - ftypes_nr[1] * UL_ALIGNMENT_WIDTH,
 			    g_size - gtypes_nr[0] * ULL_ALIGNMENT_WIDTH
@@ -1341,6 +1350,7 @@ int remap_struct(unsigned int gtypes_nr[], unsigned int ftypes_nr[],
 		    (gtypes_nr[0] * ULL_ALIGNMENT_WIDTH +
 		     ftypes_nr[1] * UL_ALIGNMENT_WIDTH + n > b_size))
 			return -1;
+
 		memmove(((char *) ps) + gtypes_nr[0] * ULL_ALIGNMENT_WIDTH
 				      + gtypes_nr[1] * UL_ALIGNMENT_WIDTH,
 			((char *) ps) + gtypes_nr[0] * ULL_ALIGNMENT_WIDTH
@@ -1354,6 +1364,10 @@ int remap_struct(unsigned int gtypes_nr[], unsigned int ftypes_nr[],
 	/* Remap possible fields (like strings of chars) following int fields */
 	d = gtypes_nr[2] - ftypes_nr[2];
 	if (d) {
+		if (ftypes_nr[2] * U_ALIGNMENT_WIDTH < ftypes_nr[2])
+			/* Overflow */
+			return -1;
+
 		n = MINIMUM(f_size - ftypes_nr[0] * ULL_ALIGNMENT_WIDTH
 				   - ftypes_nr[1] * UL_ALIGNMENT_WIDTH
 				   - ftypes_nr[2] * U_ALIGNMENT_WIDTH,
@@ -1370,6 +1384,7 @@ int remap_struct(unsigned int gtypes_nr[], unsigned int ftypes_nr[],
 		     gtypes_nr[1] * UL_ALIGNMENT_WIDTH +
 		     ftypes_nr[2] * U_ALIGNMENT_WIDTH + n > b_size))
 			return -1;
+
 		memmove(((char *) ps) + gtypes_nr[0] * ULL_ALIGNMENT_WIDTH
 				      + gtypes_nr[1] * UL_ALIGNMENT_WIDTH
 				      + gtypes_nr[2] * U_ALIGNMENT_WIDTH,
@@ -1878,8 +1893,10 @@ void check_file_actlst(int *ifd, char *dfile, struct activity *act[], unsigned i
 	 * smaller than FILE_HEADER_SIZE. Remap the fields of the file header
 	 * then copy its contents to the expected  structure.
 	 */
-	remap_struct(hdr_types_nr, file_magic->hdr_types_nr, buffer,
-		     file_magic->header_size, FILE_HEADER_SIZE, file_magic->header_size);
+	if (remap_struct(hdr_types_nr, file_magic->hdr_types_nr, buffer,
+			 file_magic->header_size, FILE_HEADER_SIZE, file_magic->header_size) < 0)
+		goto format_error;
+
 	memcpy(file_hdr, buffer, FILE_HEADER_SIZE);
 	free(buffer);
 	buffer = NULL;
@@ -2110,21 +2127,19 @@ int parse_sar_opt(char *argv[], int *opt, struct activity *act[],
 
 		case 'A':
 			select_all_activities(act);
+			*flags |= S_F_OPTION_A;
 
 			/*
-			 * Force '-P ALL -I ALL -r ALL -u ALL -F'.
+			 * Force '-r ALL -u ALL -F'.
 			 * Setting -F is compulsory because corresponding activity
 			 * has AO_MULTIPLE_OUTPUTS flag set.
+			 * -P ALL / -I ALL will be set only corresponding option has
+			 * not been exlicitly entered on the command line.
 			 */
 			p = get_activity_position(act, A_MEMORY, EXIT_IF_NOT_FOUND);
 			act[p]->opt_flags |= AO_F_MEMORY + AO_F_SWAP + AO_F_MEM_ALL;
 
-			p = get_activity_position(act, A_IRQ, EXIT_IF_NOT_FOUND);
-			memset(act[p]->bitmap->b_array, ~0,
-			       BITMAP_SIZE(act[p]->bitmap->b_size));
 			p = get_activity_position(act, A_CPU, EXIT_IF_NOT_FOUND);
-			memset(act[p]->bitmap->b_array, ~0,
-			       BITMAP_SIZE(act[p]->bitmap->b_size));
 			act[p]->opt_flags = AO_F_CPU_ALL;
 
 			p = get_activity_position(act, A_FS, EXIT_IF_NOT_FOUND);
@@ -2451,13 +2466,14 @@ int parse_sar_n_opt(char *argv[], int *opt, struct activity *act[])
  * @act		Array of activities.
  *
  * OUT:
+ * @flags	Common flags and system state.
  * @act		Array of activities, with interrupts activity selected.
  *
  * RETURNS:
  * 0 on success, 1 otherwise.
  ***************************************************************************
  */
-int parse_sar_I_opt(char *argv[], int *opt, struct activity *act[])
+int parse_sar_I_opt(char *argv[], int *opt, unsigned int *flags, struct activity *act[])
 {
 	int p;
 
@@ -2470,6 +2486,7 @@ int parse_sar_I_opt(char *argv[], int *opt, struct activity *act[])
 			     act[p]->bitmap->b_size, K_SUM))
 			return 1;
 		(*opt)++;
+		*flags |= S_F_OPTION_I;
 		return 0;
 	}
 
@@ -2504,12 +2521,44 @@ int parse_sa_P_opt(char *argv[], int *opt, unsigned int *flags, struct activity
 			     act[p]->bitmap->b_size, K_LOWERALL))
 			return 1;
 		(*opt)++;
+		*flags |= S_F_OPTION_P;
 		return 0;
 	}
 
 	return 1;
 }
 
+/*
+ ***************************************************************************
+ * If option -A has been used, force -P ALL -I ALL only if corresponding
+ * option has not been explicitly entered on the command line.
+ *
+ * IN:
+ * @flags	Common flags and system state.
+ *
+ * OUT:
+ * @act		Array of selected activities.
+ ***************************************************************************
+ */
+void set_bitmaps(struct activity *act[], unsigned int *flags)
+{
+	int p;
+
+	if (!USE_OPTION_P(*flags)) {
+		/* Force -P ALL */
+		p = get_activity_position(act, A_CPU, EXIT_IF_NOT_FOUND);
+		memset(act[p]->bitmap->b_array, ~0,
+		       BITMAP_SIZE(act[p]->bitmap->b_size));
+	}
+
+	if (!USE_OPTION_I(*flags)) {
+		/* Force -I ALL */
+		p = get_activity_position(act, A_IRQ, EXIT_IF_NOT_FOUND);
+		memset(act[p]->bitmap->b_array, ~0,
+		       BITMAP_SIZE(act[p]->bitmap->b_size));
+	}
+}
+
 /*
  ***************************************************************************
  * Count number of comma-separated values in arguments list. For example,
