@@ -692,6 +692,10 @@ __printf_funct_t print_pcp_statistics(int *tab, int action, struct activity *act
 					pcp_def_serial_metrics(act[p]);
 					break;
 
+				case A_DISK:
+					pcp_def_disk_metrics(act[p]);
+					break;
+
 				case A_NET_DEV:
 				case A_NET_EDEV:
 					pcp_def_net_dev_metrics(act[p]);
@@ -760,6 +764,34 @@ __printf_funct_t print_pcp_statistics(int *tab, int action, struct activity *act
 				case A_NET_UDP6:
 					pcp_def_net_udp6_metrics();
 					break;
+
+				case A_HUGE:
+					pcp_def_huge_metrics();
+					break;
+
+				case A_PWR_FAN:
+					pcp_def_pwr_fan_metrics(act[p]);
+					break;
+
+				case A_PWR_TEMP:
+					pcp_def_pwr_temp_metrics(act[p]);
+					break;
+
+				case A_PWR_IN:
+					pcp_def_pwr_in_metrics(act[p]);
+					break;
+
+				case A_PWR_USB:
+					pcp_def_pwr_usb_metrics(act[p]);
+					break;
+
+				case A_FS:
+					pcp_def_filesystem_metrics(act[p]);
+					break;
+
+				case A_NET_FC:
+					pcp_def_fchost_metrics(act[p]);
+					break;
 			}
 		}
 	}
@@ -1501,7 +1533,9 @@ __nr_t count_new_filesystem(struct activity *a, int curr)
 	for (i = 0; i < a->nr[curr]; i++) {
 		sfc = (struct stats_filesystem *) ((char *) a->buf[curr] + i * a->msize);
 
-		nr += add_list_item(&(a->item_list), sfc->fs_name, MAX_FS_LEN);
+		nr += add_list_item(&(a->item_list),
+				    DISPLAY_MOUNT(a->opt_flags) ? sfc->mountp : sfc->fs_name,
+				    MAX_FS_LEN);
 	}
 
 	return nr;
@@ -1579,7 +1613,7 @@ void init_custom_color_palette()
 	unsigned int val;
 
 	/* Read S_COLORS_PALETTE environment variable */
-	if ((e = getenv(ENV_COLORS_PALETTE)) == NULL)
+	if ((e = __getenv(ENV_COLORS_PALETTE)) == NULL)
 		/* Environment variable not set */
 		return;
 
