@@ -427,7 +427,7 @@ void write_stats_avg(int curr, int read_from_file, unsigned int act_id)
 int write_stats(int curr, int read_from_file, long *cnt, int use_tm_start,
 		int use_tm_end, int reset, unsigned int act_id, int reset_cd)
 {
-	int i;
+	int i, prev_hour;
 	unsigned long long itv;
 	static int cross_day = 0;
 
@@ -457,6 +457,7 @@ int write_stats(int curr, int read_from_file, long *cnt, int use_tm_start,
 	if (sa_get_record_timestamp_struct(flags + S_F_LOCAL_TIME, &record_hdr[!curr],
 					   &rectime))
 		return 0;
+	prev_hour = rectime.tm_hour;
 	set_record_timestamp_string(flags, &record_hdr[!curr],
 				    NULL, timestamp[!curr], TIMESTAMP_LEN, &rectime);
 
@@ -467,10 +468,15 @@ int write_stats(int curr, int read_from_file, long *cnt, int use_tm_start,
 	set_record_timestamp_string(flags, &record_hdr[curr],
 				    NULL, timestamp[curr], TIMESTAMP_LEN, &rectime);
 
-	/* Check if we are beginning a new day */
+	/*
+	 * Check if we are beginning a new day.
+	 * Use rectime.tm_hour and prev_hour instead of record_hdr[].hour for comparison
+	 * to take into account the current timezone (hours displayed will depend on the
+	 * TZ variable value).
+	 */
 	if (use_tm_start && record_hdr[!curr].ust_time &&
 	    (record_hdr[curr].ust_time > record_hdr[!curr].ust_time) &&
-	    (record_hdr[curr].hour < record_hdr[!curr].hour)) {
+	    (rectime.tm_hour < prev_hour)) {
 		cross_day = 1;
 	}
 
@@ -1317,7 +1323,7 @@ int main(int argc, char **argv)
 
 		else if (!strcmp(argv[opt], "-I")) {
 			/* Parse -I option */
-			if (parse_sar_I_opt(argv, &opt, act)) {
+			if (parse_sar_I_opt(argv, &opt, &flags, act)) {
 				usage(argv[0]);
 			}
 		}
@@ -1490,6 +1496,10 @@ int main(int argc, char **argv)
 		fprintf(stderr, _("-f and -o options are mutually exclusive\n"));
 		exit(1);
 	}
+	if (USE_OPTION_A(flags)) {
+		/* Set -P ALL -I ALL if needed */
+		set_bitmaps(act, &flags);
+	}
 	/* Use time start or option -i only when reading stats from a file */
 	if ((tm_start.use || INTERVAL_SET(flags)) && !from_file[0]) {
 		fprintf(stderr,
@@ -1594,7 +1604,7 @@ int main(int argc, char **argv)
 
 #ifdef TEST
 		if (__unix_time) {
-			sprintf(ltemp, "--unix_time=%llu", __unix_time);
+			sprintf(ltemp, "--unix_time=%ld", __unix_time);
 			salloc(args_idx++, ltemp);
 		}
 #endif
