@@ -2140,21 +2140,22 @@ __print_funct_t xml_print_fchost_stats(struct activity *a, int curr, int tab,
 				       unsigned long long itv)
 {
 	int i, j, j0, found;
-	struct stats_fchost *sfcc, *sfcp;
+	struct stats_fchost *sfcc, *sfcp, sfczero;
 
 	if (!IS_SELECTED(a->options) || (a->nr[curr] <= 0))
 		goto close_xml_markup;
 
+	memset(&sfczero, 0, sizeof(struct stats_fchost));
+
 	xml_markup_network(tab, OPEN_XML_MARKUP);
 	tab++;
 
 	for (i = 0; i < a->nr[curr]; i++) {
 
 		found = FALSE;
+		sfcc = (struct stats_fchost *) ((char *) a->buf[curr] + i * a->msize);
 
 		if (a->nr[!curr] > 0) {
-			sfcc = (struct stats_fchost *) ((char *) a->buf[curr] + i * a->msize);
-
 			/* Look for corresponding structure in previous iteration */
 			j = i;
 
@@ -2177,8 +2178,10 @@ __print_funct_t xml_print_fchost_stats(struct activity *a, int curr, int tab,
 			while (j != j0);
 		}
 
-		if (!found)
-			continue;
+		if (!found) {
+			/* This is a newly registered host */
+			sfcp = &sfczero;
+		}
 
 		xprintf(tab, "<fchost name=\"%s\" "
 			"fch_rxf=\"%.2f\" "
@@ -2189,7 +2192,7 @@ __print_funct_t xml_print_fchost_stats(struct activity *a, int curr, int tab,
 			S_VALUE(sfcp->f_rxframes, sfcc->f_rxframes, itv),
 			S_VALUE(sfcp->f_txframes, sfcc->f_txframes, itv),
 			S_VALUE(sfcp->f_rxwords,  sfcc->f_rxwords,  itv),
-			S_VALUE(sfcp->f_txwords,  sfcc->f_rxwords,  itv));
+			S_VALUE(sfcp->f_txwords,  sfcc->f_txwords,  itv));
 	}
 	tab--;
 
